#!/usr/bin/env python
#
#------------------------------------------------------------------------------------------------
# Extracts the versions for the daemons, applications -n, driver, browsers and anti-phishing plugins
#------------------------------------------------------------------------------------------------
#
# bdmac@bitdefender.com
# Copyright 2011 Bitdefender. All rights reserved.
#
#	$Rev: 9628 $:  Revision of last commit
#	$Date: 2015-07-21 18:14:01 +0300 (Tue, 21 Jul 2015) $:  Date of last commit
#

from optparse import OptionParser, OptionGroup
import commands
import os
import sys
import zipfile
import shutil
import time
import logging
import plistlib
import codecs
import glob
import platform
from subprocess import Popen, PIPE, call


#########################################
# Display a simple welcome message first.
#########################################

print ""
print "Welcome to the Bitdefender Profiler Tool."
print ""

#####################################################
##### Define the command line options list ##########
#####################################################

parser  = OptionParser(usage = "usage: %prog [options]    \n"
							   "       default options:	obtain versions, verbose off, system profiler detail level mini\n"
							   "       default destination:		~/Desktop/Bitdefender_Profile_output.zip\n",
					   version =  "%prog " + " $Rev: 9628 $".strip("$ ").split(' ')[1] )
parser.add_option("-o", "--output", dest="path", action='store', type="string", default="", help="The output file path. Eg: /Users/Shared/BitdefenderProfile_output.zip")
parser.add_option("-n", "--noprofile", dest="noprofile", action='store_true', default=False, help="Use this option if you don't want to provide a system profile file") 
parser.add_option("-p", "--profile", dest="level", action='store', type='choice', choices=["mini", "basic", "full"], default=False, help="Choose system profiler detail level - mini, basic, full")
parser.add_option("-v", "--verbose", dest="verbose", action='store_true', default=False, help="Run script in verbose mode, showing commands as they are run")  

guiGroup = OptionGroup(parser, "GUI options", "Options useful when running the script from a GUI application.")
guiGroup.add_option("-l", "--noelevation", dest="noelevation", action='store_true', default=False, help="Don't ask the user for elevation (needed to show the root BD daemons)")
guiGroup.add_option("-w", "--nowait", dest="nowait", action='store_true', default=False, help="Go faster when verbose (don't slow down for a nicer log)") 
guiGroup.add_option("-g", "--gui", dest="gui", action='store_true', default=False, help="apply all the GUI options (including verbose)")
parser.add_option_group(guiGroup)

(options, args) = parser.parse_args()

if options.gui:
	options.noelevation	= True
	options.nowait		= True
	options.verbose		= True

commonCommands = [
					'ps -A | grep fender',
					'launchctl list | grep fender',
					'kextstat | grep fender',
					'cat /var/log/system.log | grep efender',
				]

# !!!:landron:20101228:	separated from the common commands to have the password requested only when needed 
commonCommandsRoot = [ 
						'sudo launchctl list | grep fender',
				]

#####################################################
##### Other Constants ###############################
#####################################################
install_log 		= '/private/var/log/install.log'
TimeMachine_cmd2 	= "tmutil destinationinfo | grep 'Mount Point' | cut -d ':' -f 2 | sed -e 's/^ *//g' -e 's/ *$//g'"
TimeMachine_cmd3	= 'defaults read /Library/Preferences/com.apple.TimeMachine.plist Destinations'
varTmp				= '/private/var/tmp/BDProfile_output/'
bdProfilePath		= os.path.join(varTmp, 'BD_Profile_output.txt')
sysProfilePath		= os.path.join(varTmp, 'System_Profile_output.txt')
BDCoreIssues_History_Log_path = os.path.join(varTmp, 'com.bitdefender.coreissues.history.plist')
Unresolved_items_list_dest = os.path.join(varTmp, 'com.bitdefender.coreissues.antivirus.plist')
Unresolved_items_list_withbackslash = '/Library/Application\ Support/Antivirus\ for\ Mac/Logs/com.bitdefender.coreissues.antivirus.plist'
Unresolved_items_list_source =  '/Library/Preferences/com.apple.TimeMachine.plist'
tmpExtensionPath	= '/private/var/tmp/plugin-safari-rbl.safariextension'
tmpTLLExtensionPath	= '/private/var/tmp/TrafficLight.safariextension'
newKitPath 			= '/Library/Bitdefender/AVP/'
oldKitPath = '/Library/Bitdefender/'
userLogsPath = os.getenv('HOME') + '/Library/Logs/'
systemLogsPath = '/Library/Logs/'
zipFilePath = varTmp + 'BitdefenderProfile_output.zip'
Chrome = '/Applications/Google Chrome.app'
SafariextPath=os.path.expanduser('~/Library/Safari/Extensions/')
safari_pref=os.path.expanduser('~/Library/Preferences/com.apple.Safari.plist')
ChromePreferences = os.path.expanduser('~/Library/Application Support/Google/Chrome/Default/Preferences')
ChromeExtensions = os.path.expanduser('~/Library/Application Support/Google/Chrome/Default/Extensions')
alafile = os.path.expanduser('~/Desktop/alaa.plist')
Agent = '/Agent/agent.app/Contents/MacOS/agent'
files =  ['/Applications/Uninstall Genieo',os.getenv('HOME')+'/Library/LaunchAgents/com.genieo.completer.download.plist','/usr/lib/libgenkit.dylib','/usr/lib/libgenkitsa.dylib','/usr/lib/libimckit.dylib','/usr/lib/libimckitsa.dylib', os.getenv('HOME') + '/Library/LaunchAgents/com.genieo.completer.update.plist','/Library/LaunchAgents/com.genieoinnovation.macextension.plist','/Library/LaunchAgents/com.genieoinnovation.macextension.client.plist','/Library/LaunchAgents/com.genieo.engine.plist','/Library/LaunchAgents/com.genieo.completer.update.plist','/Library/LaunchDaemons/com.genieoinnovation.macextension.client.plist','/Library/PrivilegedHelperTools/com.genieoinnovation.macextension.client','/Library/LaunchAgents/com.vsearch.agent.plist','/Library/LaunchDaemons/com.vsearch.daemon.plist','/Library/LaunchDaemons/com.vsearch.helper.plist','/Library/LaunchDaemons/Jack.plist','/Library/LaunchAgents/com.conduit.loader.agent.plist', os.getenv('HOME')+'/Library/Internet Plug-Ins/ConduitNPAPIPlugin.plugin' ]
dirs = [os.getenv('HOME')+'/Library/Application Support/com.genieoinnovation.Installer/','/Library/Frameworks/GenieoExtra.Framework', '/Applications/Uninstall IM Completer.app', os.getenv('HOME') + '/Library/Application Support/Genieo/','/Library/Application Support/VSearch','/System/Library/Frameworks/VSearch.framework','/Library/PrivilegedHelperTools/Jack','/Applications/Genieo.app','/Library/InputManagers/CTLoader/','/Library/Application Support/SIMBL/Plugins/CT2285220.bundle','/Library/Application Support/Conduit/',os.getenv('HOME')+ '/Library/Application Support/Conduit/']
launchd = '/private/etc/launchd.conf'
SpeedUpMacpath = '/Applications/SpeedUpMac.app'
BDCoreIssues_History_Log = '/Library/Application\ Support/Antivirus\ for\ Mac/Logs/com.bitdefender.coreissues.history.plist'
BDCoreIssues_History_Log_without_backslash = '/Library/Application Support/Antivirus for Mac/Logs/com.bitdefender.coreissues.history.plist'
keep_phrases = ["Administrator authorization granted.",
			  "Displaying 'Install Succeeded' UI.",
			  "User picked Standard Install",
			  "Choices selected for installation:",
			  "./preinstall",
			  "./postinstall",
			  "PackageKit",
			  "Running install actions",
			  "Removing temporary director",
			  "Notifying system of updated components",
			  "Opened from:",
			  "packages=(",
			  "launchctl: Couldn't stat",
			  "unload console with sudo:",
			  "Free space on ",
			  "LSExceptions ",
			  "==== Uninstall Channel Product",
			  "unload console with sudo:",
			  "Remove Files&Folders.",
			  "Uninstall Appstore Product",
			  "Antivirus for Mac  Installation Log",
			  "Product archive",
			  "Displaying 'Install Failed' UI."]

#####################################################
##### Enterprise File Constants #####################
#####################################################

EntAppSupportFolder     = "/Library/Application Support/Antivirus for Mac/Enterprise"
EntSettingsFolder       = "/Library/Bitdefender/AVP/enterprise.bundle"
EntSettingsFiles        = ["epag.jso", "epag.jso.bak", "epag.db", "proxy.jso"]

#####################################################
##### Common Function ###############################
#####################################################

def CopyFile(src, dst):
    if os.path.isfile(src):
        shutil.copyfile(src, dst)

def CopyFolder(src, dst):
    if os.path.isdir(src):
        shutil.copytree(src, dst)

#####################################################
##### Daemons and Application Versions Function #####
#####################################################

# http://stackoverflow.com/questions/1383254/logging-streamhandler-and-standard-streams

def PrintState(message, alignmentDots, before=True, error=False):

	log = logging.getLogger()

	if before and alignmentDots:
		if error:
			log.warning('*'*alignmentDots)
		else:
			log.info('*'*alignmentDots)
	if error:
		log.warning(message)
	else:
		log.info(message)
	if alignmentDots:
		if error:
			log.warning('*'*alignmentDots)
		else:
			log.info('*'*alignmentDots)
logging.basicConfig()		
#	logging.getLogger().flush()
	
def BDProfiler():

# Create the temporary folder

	if not os.path.isdir(varTmp):	
		os.mkdir(varTmp)
# Create a file in which to write the commands' output on user's desktop
	bdProfileFile = open(bdProfilePath, 'w')		
	print >>bdProfileFile, '*'*20
	print >>bdProfileFile, os.path.basename(sys.argv[0]) + ' ' + parser.version.split(' ')[1]
	print >>bdProfileFile, '*'*20
	print >>bdProfileFile, 'OS: ' + platform.mac_ver()[0] + '\n'

# Get usernames in /Users
	print >>bdProfileFile, '*'*17
	print >>bdProfileFile, "User home folders"
	print >>bdProfileFile, '*'*17
	if not options.nowait:
		time.sleep(1)

	if options.verbose:
		PrintState("Getting the user home folders", 29)
		
	userList = os.listdir('/Users')
	for userName in userList:
		userHomeFolder = '/Users/' + userName 
		if os.path.isdir(userHomeFolder):
			print >>bdProfileFile, userHomeFolder
# Adware related stuff - azavoianu, 04 2015
	LA_list = os.listdir('/Library/LaunchAgents/')
	print >>bdProfileFile, "\n LaunchAgents(root)"
	print >>bdProfileFile, LA_list
	if os.path.isdir(os.getenv('HOME') + '/LibraryLaunchAgents'):
		LA_user_list = os.listdir(os.getenv('HOME') + '/Library/LaunchAgents/')
		print >>bdProfileFile, "\n LaunchAgents (user)"
		print >>bdProfileFile, LA_user_list
	LD_list = os.listdir('/Library/LaunchDaemons')
	print >>bdProfileFile, "\n LaunchDaemons(root)"
	print >>bdProfileFile, LD_list
	vsearch_list = os.listdir('/Library/Application Support/')
	for folder in vsearch_list:
		agent_='/Library/Application Support' + folder + Agent
		if os.path.isdir(agent_):
			print >>bdProfileFile, 'Fisierul %s a fost gasit pe sistem' % agent_
	s=0
	for i in range (0,len(files)):
			if os.path.isfile(files[i]):
				print >>bdProfileFile,'Fisierul/fisierele %s , ' % files[i]
				s=1
	if s:
		print >>bdProfileFile, 'au fost gasite pe sistem'
	s=0
	for i in range(0,len(dirs)):
			if os.path.isdir(dirs[i]):
				print >>bdProfileFile,'Directorul/directoarele %s ' % dirs[i]
				s=1
	if s:
		print >>bdProfileFile, 'au fost gasite pe sistem'	
	if os.path.isfile(launchd):
		if 'setenv DYLD_INSERT_LIBRARIES /usr/lib/libimckit.dylib' in commands.getoutput('cat %s' % launchd):
			print >>bdProfileFile, 'intrarea setenv DYLD_INSERT_LIBRARIES /usr/lib/libimckit.dylib exista in launchd.conf'
	else:
		print >>bdProfileFile, "\nlaunchd.conf nu exista\n"



# Daemons, Applications, Libraries Versions
	if options.verbose:
		PrintState("Determining the daemon and application versions",47)
	print >>bdProfileFile, '*'*33
	print >>bdProfileFile, "Daemons and applications versions"
	print >>bdProfileFile, '*'*33

	def processDirectory( args, dirname, filenames ):                              
	
		systemLogsPath = '/Library/Logs/'                                     
		userLogsPath   = os.getenv('HOME') + '/Library/Logs/'
		
		for filename in filenames:
			
			if (processDirectoryPath in newKitPath) or (processDirectoryPath in oldKitPath):
				pathname = os.path.join(dirname, filename)
				basename, extension = os.path.splitext(pathname)
				if ('Resources' not in basename) and ((not extension) or (pathname.endswith('dylib'))):
					commandString = 'strings ' + pathname + ' | grep  PROJECT:'
					versionCommand = commands.getstatusoutput(commandString)
					if  versionCommand[0] != 0:
						pass
					else:	
						if options.verbose:
							PrintState("Running the \"%s\" command...\n" % commandString, 0)
							if not options.nowait:
								time.sleep(1)
						print >>bdProfileFile, versionCommand[1] 
			elif (processDirectoryPath in systemLogsPath) or (processDirectoryPath in userLogsPath):
				if ('Bitdefender' in filename) or ('Kernel' in filename):
					pathname = os.path.join(dirname, filename)
					shutil.copy(pathname, varTmp)
	print >>bdProfileFile, "\n" + '*'*20
	print >>bdProfileFile, 'Kit version %s' % commands.getoutput('defaults read /Library/Bitdefender/AVP/AntivirusforMac.app/Contents/Info.plist CFBundleVersion')
	print >>bdProfileFile, '*'*20
	if os.path.isdir(newKitPath):
		print >>bdProfileFile, 'BD \n'
		processDirectoryPath = newKitPath
	elif os.path.isdir(oldKitPath):
		processDirectoryPath = oldKitPath
	else:	 
		PrintState("Error! Bitdefender folder could not be found. Exiting...", 60, False, True)
		time.sleep(1)	 
		exit()
	
	os.path.walk(processDirectoryPath, processDirectory, None )
	print >>bdProfileFile, "\n"
	#collect history log from application support
	if os.path.isfile(BDCoreIssues_History_Log_without_backslash):
		os.system('cp %s %s' %(BDCoreIssues_History_Log, BDCoreIssues_History_Log_path))
	#collect unresolved list from application support
	if os.path.isfile(Unresolved_items_list_source):
		os.system('cp %s %s' % (Unresolved_items_list_withbackslash, Unresolved_items_list_dest))
# Crash logs and panics
	if options.verbose:
			PrintState("Getting the crash and kernel panic logs", 39)
			if not options.nowait:
				time.sleep(1)
	
	processDirectoryPath   = userLogsPath
	try:
		os.path.walk(processDirectoryPath, processDirectory, None )
	

		processDirectoryPath = systemLogsPath
		os.path.walk(processDirectoryPath, processDirectory, None )
	except:
		pass
		
			
### Get the versions of Safari, Firefox and the APH extension and plugin
	systemVersion = commands.getoutput('sw_vers -productVersion').split(".")
	# if ('10.5' in systemVersion or '10.6' in systemVersion or '10.7' in systemVersion or '10.8' in systemVersion) and (os.path.isdir(newKitPath)):
	if int(systemVersion[0]) >= 10 and int(systemVersion[1]) > 4:
		if options.verbose:
			PrintState("Fetching the Browser and the Anti-phishing Plugins versions..." , 62)
			if not options.nowait:
				time.sleep(1)
		
		print >>bdProfileFile, '*'*16
		print >>bdProfileFile, "Browser Details"
		print >>bdProfileFile, '*'*16 
		
# Safari Version	
		safariVersion		= 'defaults read /Applications/Safari.app/Contents/Info CFBundleShortVersionString'
		print >>bdProfileFile, "Safari Version: %s" % commands.getoutput(safariVersion)
		# Installed Safari TLL Plugin Version
		safariTLLPath = os.getenv('HOME') + '/Library/Safari/Extensions/TrafficLight.safariextz'		
		if ( os.path.isfile(safariTLLPath) ):
			unarchTLL			= 'xar -xf ~/Library/Safari/Extensions/TrafficLight.safariextz Info.plist -C /private/var/tmp'						
			os.system(unarchTLL)
			installedSafariTLLVersion  = 'defaults read /private/var/tmp/TrafficLight.safariextension/Info | grep CFBundleShortVersionString'
			installedTLLVersionString	 = commands.getoutput(installedSafariTLLVersion)  
			print >>bdProfileFile, "Installed TrafficLight for Safari Version: %s" % installedTLLVersionString.lstrip("CFBundleShortVersionString = ")
			try:	
				shutil.rmtree(tmpTLLExtensionPath)	
			except OSError:
				pass
		else:
			print >>bdProfileFile, "\nSafari TrafficLight not installed"
					
		print >>bdProfileFile, "\n"
		if os.path.isdir(SafariextPath):
			print >>bdProfileFile, 'Safari Extensions %s' % os.listdir(SafariextPath)   
			if os.path.isfile(safari_pref):
				f = os.path.expanduser('~/Library/Preferences/com.apple.Safari.plist')
				plistlib.writePlist('', alafile)
				os.system('cp %s %s' % (f, alafile))
				call(['plutil','-convert','xml1', alafile])
				
				try:
					print >>bdProfileFile, '\n Safari SeachEngine %s' % commands.getoutput('defaults read %s SearchProfiderIdentifier' % alafile)
					print >>bdProfileFile, '\n Safari SearchEngine %s' % commands.getoutput('defaults read %s ExtensionSettings-com.genieo.safari-K444F5Z2ZH' % alafile)
					print >>bdProfileFile, '\n Safari Homepage %s' % commands.getoutput('defaults read %s HomePage' % alafile)
				except:
					pass

			else:
				print >>bdProfileFile, '\n Safari nu a fost niciodata pornit'
		print >>bdProfileFile, '*'*16 

		
# Firefox Version		
		firefoxPath			= '/Applications/Firefox.app/'
		if os.path.isdir(firefoxPath):
			firefoxVersion		= 'defaults read /Applications/Firefox.app/Contents/Info CFBundleShortVersionString'
			print >>bdProfileFile, "Firefox Version: %s \n" % commands.getoutput(firefoxVersion)
		else:
			print >>bdProfileFile, "Firefox is not Installed"

# Aph plugin versions			
		print >>bdProfileFile, '*'*15
		print >>bdProfileFile, "Plugin Versions"
		print >>bdProfileFile, '*'*15 
		
# Installed Firefox Aph Plugin Version
		firefoxProfilePath = os.getenv('HOME') + '/Library/Application Support/Firefox/Profiles'
		if os.path.exists(firefoxProfilePath):
			firefoxProfileList = os.listdir(firefoxProfilePath)
			for profileName in firefoxProfileList:
				firefoxExtPath	= os.getenv('HOME') + '/Library/Application Support/Firefox/Profiles/' + profileName + '/extensions/'
				if os.path.isdir(firefoxExtPath):
					print >>bdProfileFile, "Firefox Extensions: %s" % os.listdir(firefoxExtPath)

# Installed Firefox TLL Plugin Version
		if os.path.exists(firefoxProfilePath):
			firefoxTLLProfileList = os.listdir(firefoxProfilePath)
			for profileTLLName in firefoxTLLProfileList[1:]:
				firefoxExtSqPath = os.getenv('HOME') + '/Library/Application Support/Firefox/Profiles/' + profileTLLName + '/extensions.sqlite'
				if os.path.isfile(firefoxExtSqPath):
					extVerSq = Popen(("sqlite3 '%s' 'select version from addon where id=\"trafficlight@bitdefender.com\"'" % firefoxExtSqPath), shell=True, stdout=PIPE).communicate()[0]
					print >>bdProfileFile, "\nInstalled Firefox TrafficLight Plugin Version: %s" % extVerSq
		else:
			print >>bdProfileFile, "\nTrafficLight for Firefox not installed"



			
		print >>bdProfileFile, '*'*16 	
# Installed Chrome TLL version
		if os.path.isdir(Chrome) and os.path.isfile(ChromePreferences):
			inf_ext_chrome = ['cbmjmfcldbpelhknnfjbkobmabafpoed']
			#to_fix_later(get chrome homepage,searchengine and startupurls:
			f = codecs.open(ChromePreferences,encoding = 'utf-8')
			#for line in f:
			#	if 'http' in repr(line) and 'homepage' in repr(line):
			#		print >>bdProfileFile, 'Chrome HomePage%s' % repr(line)
			#	if '"url"' in repr(line):
			#		print >>bdProfileFile, 'Chrome Search engine %s' % repr(line)
			#	if 'startup_urls' in repr(line):
			#		print >>bdProfileFile, '\n%s Chrome startupUrls' % repr(line)  
			if os.path.isdir(ChromeExtensions):
				print >>bdProfileFile, "Chrome Extensions %s" % os.listdir(ChromeExtensions)
		else:
			print >>bdProfileFile, "Google Chrome nu este instalat"

		print >>bdProfileFile, '*'*16 						
# Other comands	
	
	for commandName in commonCommands:				
		commandResult = commands.getoutput(commandName)

		#if commandName == 'defaults read /Library/Bitdefender/AVP/AntivirusforMac.app/Contents/Info.plist CFBundleVersion':
		#	if options.verbose:
		#		PrintState("Finding the installed kit version", 55)
		#		if not options.nowait:
		#			time.sleep(1)
		#	print >>bdProfileFile, '*'*21
		#	print >>bdProfileFile, "Installed Kit Version"
		#	print >>bdProfileFile, '*'*21 
		#	commandResult = commandResult()
		

		if commandName == 'ps -A | grep fender':
			if options.verbose:
				PrintState("Determining running daemons and/or applications", 47)
				if not options.nowait:
					time.sleep(1)
			print >>bdProfileFile, '*'*35
			print >>bdProfileFile, "Running Daemons and/or Applications"
			print >>bdProfileFile, '*'*35 

		if commandName == 'launchctl list | grep fender':
			if options.verbose:
				PrintState("Determining user loaded agents",31)
				if not options.nowait:
					time.sleep(1)
			print >>bdProfileFile, '*'*18
			print >>bdProfileFile, "User Loaded Agents"
			print >>bdProfileFile, '*'*18 
					
		if commandName == 'kextstat | grep fender':
			if options.verbose:
				PrintState("Determining Bitdefender loaded kexts", 24)
				if not options.nowait:
					time.sleep(1)
			print >>bdProfileFile, '*'*12
			print >>bdProfileFile, "Bitdefender Loaded Kexts"
			print >>bdProfileFile, '*'*12 	
			
		if commandName == 'cat /var/log/system.log | grep efender':
			if options.verbose:
				PrintState -n("Fetching system log errors",33)
				if not options.nowait:
					time.sleep(1)
			print >>bdProfileFile, '*'*10
			print >>bdProfileFile, "System Log"
			print >>bdProfileFile, '*'*10 
			
		if options.verbose:
			PrintState("Running the \"%s\" command...\n" % commandName, 0)
			if not options.nowait:
				time.sleep(1)	
			
		print >>bdProfileFile, commandResult + "\n"*2
		

#
# Display the sudo usage requirement.
#
	adminCondition = False
	userID = commands.getoutput('id -u $USER')
	if userID and not options.noelevation:
		print "\nThe interrogation processes requires administrative privileges"
		print "because some of the installed files cannot be inquired by a normal user.\n"
		answer = raw_input("Would you like to provide an administrator password? [Y/N]\n Answer:")
		if answer in ["y", "Y", "yes", "Yes", "YES"]:
			adminCondition = True

	if adminCondition:
		for commandName in commonCommandsRoot:				
			commandResult = commands.getoutput(commandName)
			#collect log files from /Users/Shared (if enabled)
			list = os.listdir('/Users/Shared')
			for item in list:
				cmd = "cp /Users/Shared/'%s' '%s'" % (item, varTmp + item)
				if 'BDCoreIssues' in item:
					os.system(cmd)
				if 'com.bitdefender.agent' in item:
					cmd = "sudo cp /Users/Shared/'%s' '%s'" % (item, varTmp + item)
					os.system(cmd)
					cmd2 = "sudo chmod -R 777 '%s' " % (varTmp)
					os.system(cmd2)
				if 'BDLDaemon' in item:
					os.system(cmd)
			if commandName == 'sudo launchctl list | grep fender':
				if options.verbose:
					PrintState("Determining system loaded daemons",33)
					if not options.nowait:
						time.sleep(1)
				print >>bdProfileFile, '*'*21
				print >>bdProfileFile, "System Loaded Daemons"
				print >>bdProfileFile, '*'*21 	
				
			if options.verbose:
				PrintState("Running the \"%s\" command...\n" % commandName, 0)
				if not options.nowait:
					time.sleep(1)	
				
			print >>bdProfileFile, commandResult + "\n"*2
	print >>bdProfileFile, '*'*21 
	print >>bdProfileFile, "==========INSTALL LOG=========="
	if os.path.isfile(install_log):
		with open(install_log) as f:
			f = f.readlines()
		for line in f:
			for phrase in keep_phrases:
				if phrase in line and 'bitdefender' in line:
					print >>bdProfileFile, line
					break
	print >>bdProfileFile, '*'*21 				

# Close the BD profile file
	bdProfileFile.close()


def BDEntProfiler():
    CopyFolder(EntAppSupportFolder, os.path.join(varTmp, "Enterprise"))
    if os.path.isdir(EntSettingsFolder):
        for file in EntSettingsFiles:
            CopyFile(os.path.join(EntSettingsFolder, file), os.path.join(varTmp, file))


#####################################################
##### System Profiler Function ######################
#####################################################

def SystemProfiler():

# Make a file with the system profile according to the default or selected option
	if options.noprofile:
		return 0
	
	mini_profile  = 'system_profiler -detailLevel mini'
	basic_profile = 'system_profiler -detailLevel basic'
	full_profile  = 'system_profiler -detailLevel full'
	
	sysProfileFile = open(sysProfilePath, 'w')
	
	print >>sysProfileFile, '*'*100
	print >>sysProfileFile, os.path.basename(sys.argv[0]) + ' ' + parser.version.split(' ')[1]
	print >>sysProfileFile, '*'*100 + '\n'
	if os.path.isdir(SpeedUpMacpath):
		print >>sysProfileFile, 'SpeedUpMac este instalat pe sistem, provoaca conflict cu fisierul de preferinte com.bitdefender.antivirusformac.plist'
	else:
		print >>sysProfileFile, 'SpeedUpMac nu este instalat pe sistem'
	print >>sysProfileFile, '*'*100 + '\n'														
	GateKeeper_setting = 'spctl --status'
	gatekeeper = commands.getoutput(GateKeeper_setting)
	if 'enabled' in gatekeeper:
		print >>sysProfileFile, 'Gatekeeper is set to install apps only from Appstore and/or known developers'
	elif 'disabled' in gatekeeper:
		print >>sysProfileFile, 'Gatekeeper is set to install apps from anywhere'
	print >>sysProfileFile, '*'*16 + '\n'		
	TimeMachine_cmd = 'tmutil destinationinfo'
	if 'No destination alias' in commands.getoutput(TimeMachine_cmd):
		print >>sysProfileFile, 'Time Machine not configured'
	else:
		print >>sysProfileFile, commands.getoutput(TimeMachine_cmd)
		print >>sysProfileFile, commands.getoutput(TimeMachine_cmd2)
		if os.path.isfile('/Library/Preferences/com.apple.TimeMachine.plist'):
			print >>sysProfileFile, commands.getoutput(TimeMachine_cmd3)
	print >>sysProfileFile, '*'*16 + '\n'		
	if options.verbose:
		PrintState("Creating %s system profile. Please wait, this might take a while..." % options.level, 73)
		if not options.nowait:
			time.sleep(1)
	if options.level == "mini":
		print >>sysProfileFile, commands.getoutput(mini_profile) 
	elif options.level == "basic":
		print >>sysProfileFile, commands.getoutput(basic_profile)
	elif options.level == "full":
		print >>sysProfileFile, commands.getoutput(full_profile)	
	print >>sysProfileFile, '*'*16 + '\n'
	print >>sysProfileFile , commands.getoutput('/usr/sbin/system_profiler SPHardwareDataType')
	print >>sysProfileFile, '*'*16 + '\n'
	if 'Parallels' in commands.getoutput('mdfind kMDItemCFBundleIdentifier = "com.parallels.desktop.console"'):
		print >>sysProfileFile, 'Paralels este instalat pe sistem'
	else:
		print >>sysProfileFile, 'Paralels nu este instalat pe sistem'
	###### list top 5 cpu consuming processes, purgeable memory/process
	#print >>sysProfileFile, 'Top CPU time charged to me by other processes \n %s' % commands.getoutput('top -o cpu_me -l 1')
	#print >>sysProfileFile, '\n CPU time charged to other processes by me. \n %s' % commands.getoutput('top -o cpu_others -l 1')
	if not '10.7' in commands.getoutput('sw_vers -productVersion'):
		print >>sysProfileFile, '\n Top processes sorted by cpu \n %s' % commands.getoutput('top -o cpu -l 1 -n 10 -ncols 20')
		print >>sysProfileFile, '\n Top processes sorted by internal memory \n %s' % commands.getoutput('top -o mem -l 1 -n 10 -ncols 20')
		print >>sysProfileFile, '\n Top processes sorted by purgeable memory \n %s' % commands.getoutput ('top -o purg -l 1 -n 10 -ncols 20')

#####################################################
##### ZipFile  Function #############################
#####################################################	
	
def MakeZip():	
# Create the zip file containing the two profile files
	if options.path:
		zipFilePath = os.path.join(options.path, 'BitdefenderProfile_output')
		PrintState(zipFilePath, 0)
	else:
		desktopPath = os.path.join(os.getenv('HOME'), 'Desktop/')
		zipFilePath = os.path.join(desktopPath, 'BitdefenderProfile_output')

	if options.verbose:
		PrintState("Creating the zip file with the results...", 41)
		if not options.nowait:
			time.sleep(1)

	shutil.make_archive(zipFilePath, 'zip', varTmp)

	if options.path:
		PrintState("\nYou can find the BitdefenderProfile_output at %s" % options.path + 'BitdefenderProfile_output.zip', 0)
	else:
		PrintState("\nYou can find the BitdefenderProfile_output on your desktop!", 0)


#####################################################
##### Delete  Function ##############################
#####################################################

def DeleteFiles():

# Delete the zip and the profile files from the temporary location
	try:
		shutil.rmtree(varTmp.rstrip('/'))
	except OSError:
		pass	
	try:
		if os.path.isfile(alafile):
			os.system('rm -rf %s' % alafile)
	except:
		pass

		
		
#####################################################
##### Main Function #################################
#####################################################
def main():
# Check the administrator privileges and call the functions
	try:
		if options.verbose:
			logger = logging.StreamHandler(sys.stdout)
			logger.setLevel(logging.INFO)
			logging.getLogger().addHandler(logger)
			logging.getLogger().setLevel(logging.INFO)
			
			PrintState("\n", 60, False)
			
		DeleteFiles()		
		BDProfiler()
		BDEntProfiler()
		SystemProfiler()
		MakeZip()
		DeleteFiles()
		
		if options.verbose:
			PrintState("\nThe script has finished!", 60, False)
		
	except KeyboardInterrupt:
	
		PrintState("\nAborted. Exiting...", 0, False, True)
		time.sleep(1)
		sys.exit(0)
		
if __name__ == "__main__":
	main()
